@@ -252,16 +252,10 @@ def set_variable_loader(config_dict, incremental_or_transfer, FromSratch=False):
     '''
     if not FromSratch:
         config_dict["train_config"].from_detection_checkpoint = True
-    if incremental_or_transfer == "incremental":
-        config_dict["train_config"].load_all_detection_checkpoint_vars = True
-    elif incremental_or_transfer == "transfer":
-        config_dict["train_config"].load_all_detection_checkpoint_vars = False
-    else:
-        raise ValueError("Please choose if you want to do transfer or incremental learning") 
 
 
 
-def edit_config(model_selected, config_output_dir, num_steps, label_map_path, record_dir, eval_number, annotation_type, 
+def edit_config(model_selected, config_dir, num_steps, label_map_path, record_dir, eval_number, annotation_type, 
                 batch_size=None, learning_rate=None, resizer_size=None, incremental_or_transfer="transfer"):
     '''
         Wrapper to edit the essential values inside the base configuration protobuf file provided with an object-detection/segmentation checkpoint.
@@ -295,12 +289,12 @@ def edit_config(model_selected, config_output_dir, num_steps, label_map_path, re
             if "-" in p:
                 ckpt_ids.append(int(p.split('-')[1].split('.')[0]))
     if len(ckpt_ids)>0:
-        ckpt_path = os.path.join(model_selected,"model.ckpt-{}".format(str(max(ckpt_ids))))
+        ckpt_path = os.path.join(model_selected,"ckpt-{}".format(str(max(ckpt_ids))))
     
     else:
-        ckpt_path = os.path.join(model_selected, "model.ckpt")
+        ckpt_path = os.path.join(model_selected, "ckpt")
 
-    configs = config_util.get_configs_from_pipeline_file(os.path.join(model_selected,'pipeline.config'))
+    configs = config_util.get_configs_from_pipeline_file(os.path.join(config_dir,'pipeline.config'))
     label_map = label_map_util.load_labelmap(label_map_path)
 
     config_util._update_train_steps(configs, num_steps)
@@ -328,8 +322,9 @@ def edit_config(model_selected, config_output_dir, num_steps, label_map_path, re
     edit_eval_config(configs, annotation_type, eval_number)
     update_num_classes(configs, label_map)
     config_proto = config_util.create_pipeline_proto_from_configs(configs)
-    config_util.save_pipeline_config(config_proto, directory=config_output_dir)
-    print(f"Configuration successfully edited and saved at {config_output_dir}")
+    config_util._update_batch_size(configs, batch_size)
+    config_util.save_pipeline_config(config_proto, directory=config_dir)
+    print(f"Configuration successfully edited and saved at {config_dir}")
 
 
 def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
@@ -345,7 +340,7 @@ def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_ev
             for f in files:
                 if not file_found:
                     if f.endswith('.config'):
-                        config = f 
+                        config = os.path.join(config,f)
                         file_found = True 
     if not file_found:
         raise FileNotFoundError('No config file found in this directory {}'.format(config))
@@ -487,7 +482,7 @@ def evaluate(metrics_dir='', config='', ckpt_dir=''):
             for f in files:
                 if not file_found:
                     if f.endswith('.config'):
-                        config = f 
+                        config = os.path.join(config,f)
                         file_found = True 
     if not file_found:
         raise FileNotFoundError('No config file found in this directory {}'.format(config))
@@ -523,7 +518,7 @@ def tf_events_to_dict(path, type=''):
             for f in files:
                 if not file_found:
                     if f.startswith('events.out'):
-                        path = f 
+                        path = os.path.join(path,f)
                         file_found = True 
     if not file_found:
         raise FileNotFoundError('No tfEvent file found in this directory {}'.format(path))
